@@ -37,7 +37,7 @@ test_that("enumpart can sample without constraints", {
         redist.run.enumpart(
             ordered_path = file.path(dir, "ordered"),
             out_path = file.path(dir, "sample"),
-            ndists = 3, all = F, n = 10)
+            ndists = 3, all = FALSE, n = 10)
     )
     m <- matrix(scan(file.path(dir, "sample.dat")), nrow = 25)
 
@@ -85,7 +85,7 @@ test_that("enumpart can sample with unit count constraints", {
     capture.output(
         redist.run.enumpart(file.path(dir, "ordered"), file.path(dir, "sample"),
             ndists = 3,
-            all = F, n = 100, lower = 4, upper = 16)
+            all = FALSE, n = 100, lower = 4, upper = 16)
     )
     m <- matrix(scan(sample_path), nrow = 25)
 
@@ -104,7 +104,7 @@ test_that("enumpart can sample with population constraints", {
     target <- sum(pop)/3
     capture.output(
         redist.run.enumpart(file.path(dir, "ordered"), file.path(dir, "sample"),
-            ndists = 3, all = T, lower = round(target*0.9), upper = round(target*1.1),
+            ndists = 3, all = TRUE, lower = round(target*0.9), upper = round(target*1.1),
             weight_path = file.path(dir, "pop"))
     )
     m <- matrix(scan(sample_path), nrow = 25)
